[.cuminc: Subset method for lists of class cuminc
Description
A subset method that preserves the class of objects of class cuminc,
allowing a subset of the curves to be selected.
Usage
# S3 method for cuminc
[(x,i,…)
Value
A list with selected components of x, with the class set to
cuminc so cuminc methods can be applied.